@@ -2,16 +2,18 @@ package Plack::Test::Server;
 use strict;
 use warnings;
 use Carp;
-use LWP::UserAgent;
+use HTTP::Request;
+use HTTP::Response;
 use Test::TCP;
 use Plack::Loader;
+use Plack::LWPish;
 
 sub test_psgi {
     my %args = @_;
 
     my $client = delete $args{client} or croak "client test code needed";
     my $app    = delete $args{app}    or croak "app needed";
-    my $ua     = delete $args{ua} || LWP::UserAgent->new;
+    my $ua     = delete $args{ua} || Plack::LWPish->new;
 
     test_tcp(
         client => sub {
@@ -29,6 +31,7 @@ sub test_psgi {
             my $port = shift;
             my $server = Plack::Loader->auto(port => $port, host => ($args{host} || '127.0.0.1'));
             $server->run($app);
+            exit;
         },
     );
 }
